module Backup.Archive
    (
      createBackupArchive
    , backupDirsToEntries
    , fileMetadataToEntries
    , diffPath
    , fullPath
    , BackupDir(..)
    ) where

import Backup.Directories
import Codec.Archive.Tar as Tar
import Codec.Compression.GZip as GZip
import Data.ByteString.Lazy as BS
import Data.Time as Time


createBackupArchive :: FilePath -> [Tar.Entry] -> IO ()
createBackupArchive tarPath = BS.writeFile tarPath . GZip.compress . Tar.write


backupDirsToEntries :: [BackupDir] -> IO [Tar.Entry]
backupDirsToEntries [] = return []
backupDirsToEntries (x:xs) = do
    entry <- Tar.pack (basePath x) (dirs x)
    rest <- backupDirsToEntries xs
    return $ entry ++ rest


fileMetadataToEntries :: [FileMetadata] -> IO [Tar.Entry]
fileMetadataToEntries [] = return []
fileMetadataToEntries (x:xs) = do
    entry <- Tar.pack (base (snd x)) [(fst x)]
    rest <- fileMetadataToEntries xs
    return $ entry ++ rest


fullPath :: IO String
fullPath = do
    time <- Time.getZonedTime
    let timeStr = formatTime defaultTimeLocale "%F_%a_%H-%M-%S" time
    return $ "Full_" ++ timeStr ++ ".tar.gz"


diffPath :: IO String
diffPath = do
    time <- Time.getZonedTime
    let timeStr = formatTime defaultTimeLocale "%F_%a_%H-%M-%S" time
    return $ "Diff_" ++ timeStr ++ ".tar.gz"

